@@ -36,7 +36,6 @@ seed_closure_finalize (JSObjectRef object)
   g_free (privates->cif);
   g_callable_info_free_closure (privates->info, privates->closure);
   g_base_info_unref ((GIBaseInfo *) privates->info);
-  g_base_info_unref ((GIBaseInfo *) privates->arg_info);
 
   JSValueUnprotect (eng->context, object);
 }
@@ -99,20 +98,28 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 	  arg->v_uint32 = *(guint32 *) args[i];
 	  break;
 	case GI_TYPE_TAG_LONG:
+	  arg->v_long = *(glong *) args[i];
+	  break;
 	case GI_TYPE_TAG_INT64:
-	  arg->v_int64 = *(glong *) args[i];
+	  arg->v_int64 = *(gint64 *) args[i];
 	  break;
 	case GI_TYPE_TAG_ULONG:
+	  arg->v_ulong = *(gulong *) args[i];
+	  break;
 	case GI_TYPE_TAG_UINT64:
-	  arg->v_uint64 = *(glong *) args[i];
+	  arg->v_uint64 = *(guint64 *) args[i];
 	  break;
 	case GI_TYPE_TAG_INT:
+	  arg->v_int = *(gint *) args[i];
+	  break;
 	case GI_TYPE_TAG_SSIZE:
+	  arg->v_ssize = *(gssize *) args[i];
+	  break;
 	case GI_TYPE_TAG_SIZE:
-	  arg->v_int32 = *(gint *) args[i];
+	  arg->v_size = *(gsize *) args[i];
 	  break;
 	case GI_TYPE_TAG_UINT:
-	  arg->v_uint32 = *(guint *) args[i];
+	  arg->v_uint = *(guint *) args[i];
 	  break;
 	case GI_TYPE_TAG_FLOAT:
 	  arg->v_float = *(gfloat *) args[i];
@@ -163,7 +170,7 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 	  arg->v_pointer = 0;
 	}
       jsargs[i] = seed_gi_argument_make_js (ctx, arg, arg_type, 0);
-      seed_gi_release_in_arg (g_arg_info_get_ownership_transfer (arg_info),
+      seed_gi_release_arg (g_arg_info_get_ownership_transfer (arg_info),
 			      arg_type, arg);
       g_base_info_unref ((GIBaseInfo *) arg_info);
       g_base_info_unref ((GIBaseInfo *) arg_type);
@@ -182,7 +189,7 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
       exception = 0;
     }
 
-  seed_gi_make_argument (ctx, (JSValueRef) return_value, return_type, NULL,
+  seed_gi_make_argument (ctx, (JSValueRef) return_value, return_type,
 			 &return_arg, 0);
   switch (return_tag)
     {
@@ -200,7 +207,7 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
       *(gint16 *) result = return_arg.v_int16;
       break;
     case GI_TYPE_TAG_UINT16:
-      return_arg.v_uint16 = *(guint16 *) args[i];
+      *(guint16 *) result = return_arg.v_uint16;
       break;
     case GI_TYPE_TAG_INT32:
       *(gint32 *) result = return_arg.v_int32;
@@ -209,20 +216,28 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
       *(guint32 *) result = return_arg.v_uint32;
       break;
     case GI_TYPE_TAG_LONG:
+      *(glong *) result = return_arg.v_long;
+      break;
     case GI_TYPE_TAG_INT64:
-      *(glong *) result = return_arg.v_int64;
+      *(gint64 *) result = return_arg.v_int64;
       break;
     case GI_TYPE_TAG_ULONG:
+      *(gulong *) result = return_arg.v_ulong;
+      break;
     case GI_TYPE_TAG_UINT64:
-      *(glong *) result = return_arg.v_uint64;
+      *(guint64 *) result = return_arg.v_uint64;
       break;
     case GI_TYPE_TAG_INT:
+      *(gint *) result = return_arg.v_int;
+      break;
     case GI_TYPE_TAG_SSIZE:
+      *(gssize *) result = return_arg.v_ssize;
+      break;
     case GI_TYPE_TAG_SIZE:
-      *(gint *) result = return_arg.v_int32;
+      *(gsize *) result = return_arg.v_size;
       break;
     case GI_TYPE_TAG_UINT:
-      *(guint *) result = return_arg.v_uint32;
+      *(guint *) result = return_arg.v_uint;
       break;
     case GI_TYPE_TAG_FLOAT:
       *(gfloat *) result = return_arg.v_float;
@@ -275,7 +290,7 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 SeedNativeClosure *
 seed_make_native_closure (JSContextRef ctx,
 			  GICallableInfo * info,
-			  GIArgInfo * arg_info, JSValueRef function)
+			  JSValueRef function)
 {
   ffi_cif *cif;
   ffi_closure *closure;
@@ -301,8 +316,6 @@ seed_make_native_closure (JSContextRef ctx,
 
   privates = g_new0 (SeedNativeClosure, 1);
   privates->info = (GICallableInfo *) g_base_info_ref ((GIBaseInfo *) info);
-  privates->arg_info =
-    (GIArgInfo *) g_base_info_ref ((GIBaseInfo *) arg_info);
   privates->function = function;
   privates->cif = cif;
 
